//
//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//  N o t e b o o k   H a r d w a r e   C o n t r o l   A C P I   D L L
//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//  for ASUS Notebooks
//
//  This file is provided "as is" with no expressed or implied warranty.
//  The authors accepts no liability for any damage/loss of business that
//  this product may cause.
//
//  Last Update: 28 August 2006
//
public static class ASUSTeK
{

    #region Notebook Asus M2N : class M2N
    //
    // class author: Manfred Jaider
    //
    public static class M2N
    {

        #region Class for Asus M2N LCD Brightness control : class BRIGHTNESS
        //
        // The class must have the name BRIGHTNESS
        //
        public static class BRIGHTNESS
        {
            // Default constants for the brightness class
            public const string description = "LCD Brightness Control";             // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 1;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon

            // Constants for the brightness control (NHC will need this constants)
            public const int minimum_brightness_level = 0;
            public const int maximum_brightness_level = 15;
            public const int brightness_level_step = 1;

            #region Value class for brightness_level : class BRIGHTNESS_LEVEL
            //
            public static class BRIGHTNESS_LEVEL
            {
                // Properties of the value class
                public const string description = "Current LCD brightness level";   // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int brightness_level = 0;                             // It must have the same name as the class (case are ignored)
            }
            //
            #endregion

            // Function to set the brightness (it must have the name set_brightness)
            public static bool set_brightness(int new_level)
            {
                return ACPI.METHOD.SetValue("_SB.ATKD.SPLV", new_level);
            }

            // Function to get and refresh the brightness level (it must have the name set_brightness)
            public static bool get_brightness(ref int level)
            {
                bool result = ACPI.METHOD.GetValue("_SB.ATKD.GPLV", ref level);     // get the brightness level
                BRIGHTNESS_LEVEL.brightness_level = level;
                return result;
            }
        }
        //
        #endregion

        #region Class for Asus M2N Hardware control : class HARDWARE
        //
        public static class HARDWARE
        {
            // Info
            public const string description = "Hardware Control";                   // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 0;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon

            #region Value class for OVERCLOCK : class OVERCLOCK
            //
            public static class OVERCLOCK
            {
                // Properties of the value class
                public const string description = "CPU Overlock";                   // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int overclock = 0;                                    // It must have the same name as the class (case are ignored)
                public const string unit = "   (0 = clock down; 1 = default clock; 2,3,4 = over clock)";    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 0;                         // the minimum input value
                    public const int nhc_maximum_value = 4;                         // the maximum input value
                    public const int nhc_default_value = 1;                         // the default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC start
                    {
                        int returnValue = 0;
                        return ACPI.METHOD.SetValueWithReturn("_SB.ATKD.SFRQ", overclock, ref returnValue);
                    }
                }
            }
            //
            #endregion

        }
        //
        #endregion

        #region Class for Asus M2N FAN control : class FAN
        //
        public static class FAN
        {
            // Info
            public const string description = "Notebook FAN Control";               // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 2;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon
            public static bool initialisation = false;                              // Initialisation variable: on initialisation NHC will set this variable to true; after the initialisation NHC will set this variabel to false

            // OperationRegion (\RAMW, SystemMemory, RAMB, 0xFF)
            // Field (\RAMW, ByteAcc, NoLock, Preserve)
            // {
            //     . . .
            //     . . .
            //     Offset (0xBE), 
            //     PADL,   16, 
            //     CADL,   16, 
            //     CSTE,   16, 
            //     NSTE,   16, 
            //     SSTE,   16, 
            //     SFUN,   8, 
            //     TSAD,   8, 
            //     TAC3,   8,        // 48C         <- FAN ON low level
            //     TAC2,   8,        // 68C         <- FAN ON middle level
            //     TAC1,   8,        // 78C         <- FAN ON high level
            //     TAC0,   8,        // 86C         <- FAN ON maximum level
            //     TPSV,   8,        // 105C        <- clock down
            //     TCRT,   8,        // 110C        <- turn off computer
            //     F1L0,   8,        // 254 -rmp     <- FAN OFF
            //     F2L0,   8,        // 0
            //     F1L1,   8,        // 181 -rmp     <- FAN low speed
            //     F2L1,   8,        // 0
            //     F1L2,   8,        // 149 -rmp     <- FAN middle speed
            //     F2L2,   8,        // 0
            //     F1L3,   8,        // 139 -rmp     <- FAN high speed
            //     F2L3,   8,        // 0
            //     F1L4,   8,        // 112 -rmp     <- FAN maximum speed
            //     F2L4,   8,        // 0
            //     SLPT,   8, 
            //     DBRD,   32, 
            //     SIDS,   8, 
            //     Offset (0xE3), 
            //     CPUS,   8
            // }
            //
            //  Info:   To get the above values you can use the ACPI.FIELD.Read("name", ref value) function
            //          Example: int value = 0; ACPI.FIELD.Read("TAC3", ref value);

            #region Value class for FAN_LOW_SPEED : class FAN_LOW_SPEED
            //
            public static class FAN_LOW_SPEED
            {
                // Properties of the value class
                public const string description = "FAN low speed";                  // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_low_speed = 181;                              // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm-";                                 // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 112;                       // minimum input value
                    public const int nhc_maximum_value = 254;                       // maximum input value
                    public const int nhc_default_value = 181;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.FIELD.Write("F1L1", fan_low_speed) == true)        // set the fan_low_speed value in the buffer
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.TCHG");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for FAN_MIDDLE_SPEED : class FAN_MIDDLE_SPEED
            //
            public static class FAN_MIDDLE_SPEED
            {
                // Properties of the value class
                public const string description = "FAN middle speed";               // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_middle_speed = 149;                           // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm-";                                 // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 112;                       // minimum input value
                    public const int nhc_maximum_value = 254;                       // maximum input value
                    public const int nhc_default_value = 149;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.FIELD.Write("F1L2", fan_middle_speed) == true)     // set the fan_low_speed value in the buffer
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.TCHG");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for FAN_HIGH_SPEED : class FAN_HIGH_SPEED
            //
            public static class FAN_HIGH_SPEED
            {
                // Properties of the value class
                public const string description = "FAN high speed";                 // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_high_speed = 139;                             // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm-";                                 // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 112;                       // minimum input value
                    public const int nhc_maximum_value = 254;                       // maximum input value
                    public const int nhc_default_value = 139;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.FIELD.Write("F1L2", fan_high_speed) == true)       // set the fan_low_speed value in the buffer
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.TCHG");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region  Value class for LOW_LEVEL_ON : class LOW_LEVEL_ON
            //
            public static class LOW_LEVEL_ON
            {
                // Properties of the value class
                public const string description = "FAN ON low level";               // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int low_level_on = 48;                                // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 0;                         // minimum input value
                    public const int nhc_maximum_value = 68;                        // maximum input value
                    public const int nhc_default_value = 48;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.FIELD.Write("TAC3", low_level_on) == true)         // set the low_level value in the field
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.TCHG");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region  Value class for MIDDLE_LEVEL_ON : class MIDDLE_LEVEL_ON
            //
            public static class MIDDLE_LEVEL_ON
            {
                // Properties of the value class
                public const string description = "FAN ON middle level";            // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int middle_level_on = 68;                             // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 48;                        // minimum input value
                    public const int nhc_maximum_value = 78;                        // maximum input value
                    public const int nhc_default_value = 68;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.FIELD.Write("TAC2", middle_level_on) == true)      // set the low_level value in the field
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.TCHG");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region  Value class for HIGH_LEVEL_ON : class HIGH_LEVEL_ON
            //
            public static class HIGH_LEVEL_ON
            {
                // Properties of the value class
                public const string description = "FAN ON high level";              // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int high_level_on = 78;                               // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 68;                        // minimum input value
                    public const int nhc_maximum_value = 86;                        // maximum input value
                    public const int nhc_default_value = 78;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.FIELD.Write("TAC1", high_level_on) == true)        // set the low_level value in the field
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.TCHG");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            // init function -> NHC will call this function on initialisation (after the nhc_on_write() functions)
            public static bool init()
            {
                return ACPI.METHOD.Call("_TZ.TCHG");                                // refresh the ThermalZone (Temperature and FAN Speed)
            }
        }
        //
        #endregion

    }
    //
    #endregion

    #region Notebook Asus A6T : class A6T
    //
    // class author: Manfred Jaider
    //
    public static class A6T
    {

        #region Class for Asus A6T LCD Brightness control : class BRIGHTNESS
        //
        // The class must have the name BRIGHTNESS
        //
        public static class BRIGHTNESS
        {
            // Default constants for the brightness class
            public const string description = "LCD Brightness Control";             // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 1;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon

            // Constants for the brightness control (NHC will need this constants)
            public const int minimum_brightness_level = 0;
            public const int maximum_brightness_level = 15;
            public const int brightness_level_step = 1;

            #region Value class for brightness_level : class BRIGHTNESS_LEVEL
            //
            public static class BRIGHTNESS_LEVEL
            {
                // Properties of the value class
                public const string description = "Current LCD brightness level";   // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int brightness_level = 0;                             // It must have the same name as the class (case are ignored)
            }
            //
            #endregion

            // Function to set the brightness (it must have the name set_brightness)
            public static bool set_brightness(int new_level)
            {
                return ACPI.METHOD.SetValue("_SB.ATKD.SPLV", new_level);
            }

            // Function to get and refresh the brightness level (it must have the name set_brightness)
            public static bool get_brightness(ref int level)
            {
                bool result = ACPI.METHOD.GetValue("_SB.ATKD.GPLV", ref level);     // get the brightness level
                BRIGHTNESS_LEVEL.brightness_level = level;
                return result;
            }
        }
        //
        #endregion

        #region Class for Asus A6T FAN control : class FAN
        //
        public static class FAN
        {
            // Info
            public const string description = "Notebook FAN Control";               // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 2;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon
            public static bool initialisation = false;                              // Initialisation variable: on initialisation NHC will set this variable to true; after the initialisation NHC will set this variabel to false

            // Name (HTTL, Package (0x08)       // <- silent mode package
            // {
            //    0x39,     // 57C     <- FAN ON low level
            //    0x3F,     // 63C     <- FAN ON middle level 1
            //    0x44,     // 68C     <- FAN ON middle level 2
            //    0x49,     // 73C     <- FAN ON high level 1
            //    0x4F,     // 79C     <- FAN ON high level 2
            //    0x55,     // 85C     <- FAN ON very high level
            //    0x5F,     // 94C     <- FAN ON maximum level
            //    0x73      // 115C    <- turn off computer
            // })
            // Name (LTTL, Package (0x08)       // <- silent mode package
            // {
            //    0x00,
            //    0x32,     // 50C     <- FAN OFF low level
            //    0x3A,     // 58C     <- FAN OFF middle level 1
            //    0x3F,     // 63C     <- FAN OFF middle level 2
            //    0x44,     // 68C     <- FAN OFF high level 1
            //    0x49,     // 73C     <- FAN OFF high level 2
            //    0x50,     // 80C     <- FAN OFF very high level
            //    0x5A      // 90C     <- FAN OFF maximum level
            // })
            // Name (FSTL, Package (0x08)       // <- silent mode package
            // {
            //    0x00,     // FAN off
            //    0x72,     // 114*rmp  <- FAN Low
            //    0x88,     // 136*rmp  <- FAN middle speed 1
            //    0xA0,     // 169*rmp  <- FAN middle speed 2
            //    0xC4,     // 196*rmp  <- FAN high speed 1
            //    0xE5,     // 229*rmp  <- FAN high speed 2
            //    0xE5,     // 229*rmp  <- FAN very high speed
            //    0xE5      // 229*rmp  <- FAN maximum speed
            // })
            // Name (HTTS, Package (0x08)
            // {
            //    0x35,     // 53C     <- FAN ON low level
            //    0x3B,     // 59C     <- FAN ON middle level 1
            //    0x40,     // 64C     <- FAN ON middle level 2
            //    0x45,     // 69C     <- FAN ON high level 1
            //    0x45,     // 69C     <- FAN ON high level 2
            //    0x55,     // 85C     <- FAN ON very high level
            //    0x5F,     // 95C     <- FAN ON maximum level
            //    0x73      // 115C    <- turn off computer
            // })
            // Name (LTTS, Package (0x08)
            // {
            //    0x00, 
            //    0x30,     // 48C     <- FAN OFF low level
            //    0x35,     // 53C     <- FAN OFF middle level 1
            //    0x3B,     // 59C     <- FAN OFF middle level 2
            //    0x3B,     // 59C     <- FAN OFF high level 1
            //    0x40,     // 64C     <- FAN OFF high level 2
            //    0x50,     // 80C     <- FAN OFF very high level
            //    0x5A      // 90C     <- FAN OFF maximum level
            // })
            // Name (FSTS, Package (0x08)
            // {
            //    0x00,     // FAN off
            //    0x72,     // 114*rmp  <- FAN Low
            //    0x92,     // 146*rmp  <- FAN middle speed 1
            //    0xB6,     // 182*rmp  <- FAN middle speed 2
            //    0xE5,     // 229*rmp  <- FAN high speed 1
            //    0xE5,     // 229*rmp  <- FAN high speed 2
            //    0xE5,     // 229*rmp  <- FAN very high speed
            //    0xE5      // 229*rmp  <- FAN maximum speed
            // })
            //

            #region Value class for FAN_LOW_SPEED : class FAN_LOW_SPEED
            //
            public static class FAN_LOW_SPEED
            {
                // Properties of the value class
                public const string description = "FAN low speed";                  // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_low_speed = 114;                              // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm";                                  // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 50;                        // minimum input value
                    public const int nhc_maximum_value = 255;                       // maximum input value
                    public const int nhc_default_value = 114;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.FSTS", "PKG[1]", fan_low_speed) == true)    // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for FAN_MIDDLE_SPEED_1 : class FAN_MIDDLE_SPEED_1
            //
            public static class FAN_MIDDLE_SPEED_1
            {
                // Properties of the value class
                public const string description = "FAN middle speed 1";             // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_middle_speed_1 = 146;                           // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm";                                  // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 100;                       // minimum input value
                    public const int nhc_maximum_value = 255;                       // maximum input value
                    public const int nhc_default_value = 146;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.FSTS", "PKG[2]", fan_middle_speed_1) == true)   // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for FAN_MIDDLE_SPEED_2 : class FAN_MIDDLE_SPEED_2
            //
            public static class FAN_MIDDLE_SPEED_2
            {
                // Properties of the value class
                public const string description = "FAN middle speed 2";             // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_middle_speed_2 = 182;                         // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm";                                  // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 100;                       // minimum input value
                    public const int nhc_maximum_value = 255;                       // maximum input value
                    public const int nhc_default_value = 182;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.FSTS", "PKG[3]", fan_middle_speed_2) == true)   // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for FAN_HIGH_SPEED_1 : class FAN_HIGH_SPEED_1
            //
            public static class FAN_HIGH_SPEED_1
            {
                // Properties of the value class
                public const string description = "FAN high speed 1";               // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_high_speed_1 = 229;                           // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm";                                  // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 150;                       // minimum input value
                    public const int nhc_maximum_value = 255;                       // maximum input value
                    public const int nhc_default_value = 229;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.FSTS", "PKG[4]", fan_high_speed_1) == true)     // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for FAN_HIGH_SPEED_2 : class FAN_HIGH_SPEED_2
            //
            public static class FAN_HIGH_SPEED_2
            {
                // Properties of the value class
                public const string description = "FAN high speed 2";               // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int fan_high_speed_2 = 229;                           // It must have the same name as the class (case are ignored)
                public const string unit = "*rpm";                                  // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 150;                       // minimum input value
                    public const int nhc_maximum_value = 255;                       // maximum input value
                    public const int nhc_default_value = 229;                       // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.FSTS", "PKG[5]", fan_high_speed_2) == true)     // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            // - - -

            #region Value class for LOW_LEVEL_OFF : class LOW_LEVEL_OFF
            //
            public static class LOW_LEVEL_OFF
            {
                // Properties of the value class
                public const string description = "FAN OFF low level";              // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int low_level_off = 48;                               // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 0;                         // minimum input value
                    public const int nhc_maximum_value = 60;                        // maximum input value
                    public const int nhc_default_value = 48;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.LTTS", "PKG[1]", low_level_off) == true)    // set the low_level_off value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for LOW_LEVEL_ON : class LOW_LEVEL_ON
            //
            public static class LOW_LEVEL_ON
            {
                // Properties of the value class
                public const string description = "FAN ON low level";               // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int low_level_on = 53;                                // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 5;                         // minimum input value
                    public const int nhc_maximum_value = 65;                        // maximum input value
                    public const int nhc_default_value = 53;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.HTTS", "PKG[0]", low_level_on) == true)     // set the low_level_on value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for MIDDLE_LEVEL_1_OFF : class MIDDLE_LEVEL_1_OFF
            //
            public static class MIDDLE_LEVEL_1_OFF
            {
                // Properties of the value class
                public const string description = "FAN OFF middle level 1";         // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int middle_level_1_off = 53;                            // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 10;                        // minimum input value
                    public const int nhc_maximum_value = 70;                        // maximum input value
                    public const int nhc_default_value = 53;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.LTTS", "PKG[2]", middle_level_1_off) == true)   // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for MIDDLE_LEVEL_1_ON : class MIDDLE_LEVEL_1_ON
            //
            public static class MIDDLE_LEVEL_1_ON
            {
                // Properties of the value class
                public const string description = "FAN ON middle level 1";          // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int middle_level_1_on = 59;                           // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 15;                        // minimum input value
                    public const int nhc_maximum_value = 75;                        // maximum input value
                    public const int nhc_default_value = 59;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.HTTS", "PKG[1]", middle_level_1_on) == true)    // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for MIDDLE_LEVEL_2_OFF : class MIDDLE_LEVEL_2_OFF
            //
            public static class MIDDLE_LEVEL_2_OFF
            {
                // Properties of the value class
                public const string description = "FAN OFF middle level 2";         // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int middle_level_2_off = 59;                          // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 20;                        // minimum input value
                    public const int nhc_maximum_value = 70;                        // maximum input value
                    public const int nhc_default_value = 59;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.LTTS", "PKG[3]", middle_level_2_off) == true)   // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for MIDDLE_LEVEL_2_ON : class MIDDLE_LEVEL_2_ON
            //
            public static class MIDDLE_LEVEL_2_ON
            {
                // Properties of the value class
                public const string description = "FAN ON middle level 2";          // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int middle_level_2_on = 64;                           // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 25;                        // minimum input value
                    public const int nhc_maximum_value = 75;                        // maximum input value
                    public const int nhc_default_value = 64;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.HTTS", "PKG[2]", middle_level_2_on) == true)    // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for HIGH_LEVEL_1_OFF : class HIGH_LEVEL_1_OFF
            //
            public static class HIGH_LEVEL_1_OFF
            {
                // Properties of the value class
                public const string description = "FAN OFF high level 1";           // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int high_level_1_off = 59;                            // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 25;                        // minimum input value
                    public const int nhc_maximum_value = 75;                        // maximum input value
                    public const int nhc_default_value = 59;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.LTTS", "PKG[4]", high_level_1_off) == true)   // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for HIGH_LEVEL_1_ON : class HIGH_LEVEL_1_ON
            //
            public static class HIGH_LEVEL_1_ON
            {
                // Properties of the value class
                public const string description = "FAN ON high level 1";            // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int high_level_1_on = 69;                             // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 30;                        // minimum input value
                    public const int nhc_maximum_value = 80;                        // maximum input value
                    public const int nhc_default_value = 69;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.HTTS", "PKG[3]", high_level_1_on) == true)    // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for HIGH_LEVEL_2_OFF : class HIGH_LEVEL_2_OFF
            //
            public static class HIGH_LEVEL_2_OFF
            {
                // Properties of the value class
                public const string description = "FAN OFF high level 2";           // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int high_level_2_off = 64;                            // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 35;                        // minimum input value
                    public const int nhc_maximum_value = 80;                        // maximum input value
                    public const int nhc_default_value = 64;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.LTTS", "PKG[5]", high_level_2_off) == true)   // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            #region Value class for HIGH_LEVEL_2_ON : class HIGH_LEVEL_2_ON
            //
            public static class HIGH_LEVEL_2_ON
            {
                // Properties of the value class
                public const string description = "FAN ON high level 2";            // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int high_level_2_on = 69;                             // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of value

                // With this class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 40;                        // minimum input value
                    public const int nhc_maximum_value = 85;                        // maximum input value
                    public const int nhc_default_value = 69;                        // default value
                    public static bool nhc_on_write()                               // Optional function - NHC will call this function if the user change the value on runtime and on NHC initialisation
                    {
                        if (ACPI.PACKAGE.Write("_TZ.HTTS", "PKG[3]", high_level_2_on) == true)    // set the value in the package
                        {
                            if (initialisation == false)
                            {
                                return ACPI.METHOD.Call("_TZ.STRP");                // refresh the ThermalZone (Temperature and FAN Speed)
                            }
                            else
                            {
                                return true;                                        // on NHC initialisation skip the ThermalZone refresh
                            }
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }
            //
            #endregion

            // init function -> NHC will call this function on initialisation (after the nhc_on_write() functions)
            public static bool init()
            {
                return ACPI.METHOD.Call("_TZ.STRP");                                // refresh the ThermalZone (Temperature and FAN Speed)
            }
        }
        //
        #endregion

    }
    //
    #endregion

}